@@ -1,6 +1,4 @@
-"""
-This module contains regression estimators based on the sparse group lasso
-"""
+"""Create regression estimators based on the sparse group lasso."""
 import numpy as np
 
 from functools import partial
@@ -27,20 +25,13 @@ from sklearn.utils.validation import (
 
 from ._base import SGLBaseEstimator
 from ._prox import _soft_threshold
-from .utils import check_groups, ProgressParallel
+from .utils import check_groups, _ProgressParallel
 
-__all__ = []
+__all__ = ["SGL", "sgl_path", "SGLCV"]
 
 
-def registered(fn):
-    __all__.append(fn.__name__)
-    return fn
-
-
-@registered
 class SGL(SGLBaseEstimator, RegressorMixin, LinearModel):
-    """
-    An sklearn compatible sparse group lasso regressor.
+    """An sklearn compatible sparse group lasso regressor.
 
     This solves the sparse group lasso [1]_ problem for a feature matrix
     partitioned into groups using the proximal gradient descent (PGD)
@@ -108,9 +99,6 @@ class SGL(SGLBaseEstimator, RegressorMixin, LinearModel):
     n_iter_ : int
         Actual number of iterations used in the solver.
 
-    Examples
-    --------
-
     References
     ----------
     .. [1]  Noah Simon, Jerome Friedman, Trevor Hastie & Robert Tibshirani,
@@ -121,7 +109,7 @@ class SGL(SGLBaseEstimator, RegressorMixin, LinearModel):
     """
 
     def fit(self, X, y, loss="squared_loss"):
-        """Fit a linear model using the sparse group lasso
+        """Fit a linear model using the sparse group lasso.
 
         Parameters
         ----------
@@ -178,7 +166,7 @@ def _alpha_grid(
     copy_X=True,
     model=SGL,
 ):
-    """Compute the grid of alpha values for elastic net parameter search
+    """Compute the grid of alpha values for elastic net parameter search.
 
     Parameters
     ----------
@@ -256,37 +244,17 @@ def _alpha_grid(
         )
 
     n_samples = len(y)
-    sparse_center = False
     if Xy is None:
-        X_sparse = sparse.isspmatrix(X)
-        sparse_center = X_sparse and (fit_intercept or normalize)
-        X = check_array(
-            X, accept_sparse="csc", copy=(copy_X and fit_intercept and not X_sparse)
-        )
-        if not X_sparse:
-            # X can be touched inplace thanks to the above line
-            X, y, _, _, _ = _preprocess_data(X, y, fit_intercept, normalize, copy=False)
+        X = check_array(X, accept_sparse=False, copy=(copy_X and fit_intercept))
+        X, y, _, _, _ = _preprocess_data(X, y, fit_intercept, normalize, copy=False)
         Xy = safe_sparse_dot(X.T, y, dense_output=True)
 
-        if sparse_center:
-            # Workaround to find alpha_max for sparse matrices.
-            # since we should not destroy the sparsity of such matrices.
-            _, _, X_offset, _, X_scale = _preprocess_data(
-                X, y, fit_intercept, normalize, return_mean=True
-            )
-            mean_dot = X_offset * np.sum(y)
-
     if Xy.ndim == 1:
         Xy = Xy[:, np.newaxis]
 
-    if sparse_center:
-        if fit_intercept:
-            Xy -= mean_dot[:, np.newaxis]
-        if normalize:
-            Xy /= X_scale[:, np.newaxis]
-
     groups = check_groups(groups, X, allow_overlap=False, fit_intercept=False)
 
+    print(scale_l2_by)
     if scale_l2_by not in ["group_length", None]:
         raise ValueError(
             "scale_l2_by must be 'group_length' or None; " "got {0}".format(scale_l2_by)
@@ -355,7 +323,6 @@ def _alpha_grid(
     ]
 
 
-@registered
 def sgl_path(
     X,
     y,
@@ -374,7 +341,7 @@ def sgl_path(
     **params,
 ):
     """
-    Compute sparse group lasso path
+    Compute sparse group lasso path.
 
     We use the previous solution as the initial guess for subsequent alpha values
 
@@ -470,14 +437,14 @@ def sgl_path(
     if check_input:
         X = check_array(
             X,
-            accept_sparse="csc",
+            accept_sparse=False,
             dtype=[np.float64, np.float32],
             order="F",
             copy=copy_X,
         )
         y = check_array(
             y,
-            accept_sparse="csc",
+            accept_sparse=False,
             dtype=X.dtype.type,
             order="F",
             copy=False,
@@ -559,9 +526,8 @@ def sgl_path(
     return alphas, coefs, dual_gaps
 
 
-@registered
 class SGLCV(LinearModel, RegressorMixin, TransformerMixin):
-    """Class for iterative SGL model fitting along a regularization path
+    """Iterative SGL model fitting along a regularization path.
 
     Parameters
     ----------
@@ -683,7 +649,7 @@ class SGLCV(LinearModel, RegressorMixin, TransformerMixin):
         number of iterations run by the proximal gradient descent solver to
         reach the specified tolerance for the optimal alpha.
 
-    See also
+    See Also
     --------
     sgl_path
     SGL
@@ -722,7 +688,7 @@ class SGLCV(LinearModel, RegressorMixin, TransformerMixin):
         self.n_jobs = n_jobs
 
     def fit(self, X, y):
-        """Fit sparse group lasso linear model
+        """Fit sparse group lasso linear model.
 
         Fit is on grid of alphas and best alpha estimated by cross-validation.
 
@@ -758,18 +724,12 @@ class SGLCV(LinearModel, RegressorMixin, TransformerMixin):
             # csr. We also want to allow y to be 64 or 32 but check_X_y only
             # allows to convert for 64.
             check_X_params = dict(
-                accept_sparse="csc", dtype=[np.float64, np.float32], copy=False
+                accept_sparse=False, dtype=[np.float64, np.float32], copy=False
             )
             X, y = self._validate_data(
                 X, y, validate_separately=(check_X_params, check_y_params)
             )
-            if sparse.isspmatrix(X):
-                if hasattr(reference_to_old_X, "data") and not np.may_share_memory(
-                    reference_to_old_X.data, X.data
-                ):
-                    # X is a sparse matrix and has been copied
-                    copy_X = False
-            elif not np.may_share_memory(reference_to_old_X, X):
+            if not np.may_share_memory(reference_to_old_X, X):
                 # X has been copied
                 copy_X = False
             del reference_to_old_X
@@ -779,7 +739,7 @@ class SGLCV(LinearModel, RegressorMixin, TransformerMixin):
             # csr. We also want to allow y to be 64 or 32 but check_X_y only
             # allows to convert for 64.
             check_X_params = dict(
-                accept_sparse="csc",
+                accept_sparse=False,
                 dtype=[np.float64, np.float32],
                 order="F",
                 copy=copy_X,
@@ -789,9 +749,6 @@ class SGLCV(LinearModel, RegressorMixin, TransformerMixin):
             )
             copy_X = False
 
-        if y.shape[0] == 0:
-            raise ValueError("y has 0 samples: %r" % y)
-
         model = SGL()
         y = column_or_1d(y, warn=True)
 
@@ -847,7 +804,7 @@ class SGLCV(LinearModel, RegressorMixin, TransformerMixin):
         # "precompute" has no effect but it is expected by _path_residuals
         path_params["precompute"] = False
 
-        if isinstance(self.verbose, int):
+        if isinstance(self.verbose, int):  # pragma: no cover
             path_params["verbose"] = self.verbose - 1
 
         # init cross-validation generator
@@ -876,14 +833,14 @@ class SGLCV(LinearModel, RegressorMixin, TransformerMixin):
             for train, test in folds
         )
 
-        if isinstance(self.verbose, int):
+        if isinstance(self.verbose, int):  # pragma: no cover
             parallel_verbosity = self.verbose - 2
             if parallel_verbosity < 0:
                 parallel_verbosity = 0
-        else:
+        else:  # pragma: no cover
             parallel_verbosity = self.verbose
 
-        mse_paths = ProgressParallel(
+        mse_paths = _ProgressParallel(
             n_jobs=self.n_jobs,
             verbose=parallel_verbosity,
             use_tqdm=bool(self.verbose),
@@ -937,16 +894,16 @@ class SGLCV(LinearModel, RegressorMixin, TransformerMixin):
 
     @property
     def chosen_features_(self):
-        """An index array of chosen features"""
+        """Return index array of chosen features."""
         return np.nonzero(self.coef_)[0]
 
     @property
     def sparsity_mask_(self):
-        """A boolean array indicating which features survived regularization"""
+        """Return boolean array indicating which features survived regularization."""
         return self.coef_ != 0
 
     def like_nonzero_mask_(self, rtol=1e-8):
-        """A boolean array indicating which features are zero or close to zero
+        """Return boolean array indicating which features are zero or close to zero.
 
         Parameters
         ----------
@@ -960,7 +917,7 @@ class SGLCV(LinearModel, RegressorMixin, TransformerMixin):
 
     @property
     def chosen_groups_(self):
-        """A set of the group IDs that survived regularization"""
+        """Return set of the group IDs that survived regularization."""
         if self.groups is not None:
             group_mask = [
                 bool(set(grp).intersection(set(self.chosen_features_)))
@@ -971,7 +928,7 @@ class SGLCV(LinearModel, RegressorMixin, TransformerMixin):
             return self.chosen_features_
 
     def transform(self, X):
-        """Remove columns corresponding to zeroed-out coefficients"""
+        """Remove columns corresponding to zeroed-out coefficients."""
         # Check is fit had been called
         check_is_fitted(self, "is_fitted_")
 
